SupportsDefaultKeyword

Trait SupportsDefaultKeyword 

pub trait SupportsDefaultKeyword { }
Available on crate feature i-implement-a-third-party-backend-and-opt-into-breaking-changes only.
A marker trait indicating if a DEFAULT like expression is supported as part of INSERT INTO clauses to indicate that a default value should be inserted at a specific position

If you use a custom type to specify specialized support for DEFAULT expressions implementing this trait opts in support for DEFAULT value expressions for inserts. Otherwise diesel will emulate this behaviour.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors